/*
		Cbreak.cpp: Implementation of the Cbreak class

        Copyright (C) 2000 Patrick Dughi

        This software may be used and distributed according to the terms
        of the GNU Public License, incorporated herein by reference, located
		as the file gpl.txt in this same directory.

        The author may be reached at dughi@imaxx.net.

        This class controls the main application startup sequence, and initiates the message loop,
		among other things.
*/


#pragma warning(disable:4786)
#include "stdafx.h"
#include "Cbreak.h"
#include "DirDialog.h"
#include "CirclemudEditorDlg.h"
#include "Medit.h"
#include "Zedit.h"
#include "Redit.h"
#include "Oedit.h"
#include "Sedit.h"
#include "NewZoneDlg.h"
#include "World.h"
#include "Splash.h"
#include "ConstantLoader.h"

extern World the_world;
#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CCbreakApp

BEGIN_MESSAGE_MAP(CCbreakApp, CWinApp)
	//{{AFX_MSG_MAP(CCbreakApp)
	ON_COMMAND(ID_APP_ABOUT, OnAppAbout)
	ON_COMMAND(ID_FILE_NEWZONE, OnFileNewzone)
	ON_COMMAND(ID_FILE_NEWWORLD, OnFileNewworld)
	ON_COMMAND(ID_FILE_SAVEWORLD, OnFileSaveworld)
	ON_COMMAND(ID_EDIT_CLEAR, OnEditClear)
	ON_COMMAND(ID_EDIT_COPY, OnEditCopy)
	ON_COMMAND(ID_EDIT_CUT, OnEditCut)
	ON_COMMAND(ID_EDIT_PASTE, OnEditPaste)
	ON_COMMAND(ID_EDIT_SELECT_ALL, OnEditSelectAll)
	ON_COMMAND(ID_EDIT_UNDO, OnEditUndo)
	ON_COMMAND(ID_IMPROVEDEDIT_FORMAT, OnImprovededitFormat)
	ON_COMMAND(ID_IMPROVEDEDIT_FORMATI, OnImprovededitFormati)
	
	//}}AFX_MSG_MAP
	// Standard file based document commands
	ON_COMMAND(ID_FILE_NEW, CWinApp::OnFileNew)
	ON_COMMAND(ID_FILE_OPEN, CWinApp::OnFileOpen)
	// Standard print setup command
	ON_COMMAND(ID_FILE_PRINT_SETUP, CWinApp::OnFilePrintSetup)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CCbreakApp construction

CCbreakApp::CCbreakApp()
{
	// TODO: add construction code here,
	// Place all significant initialization in InitInstance
}

/////////////////////////////////////////////////////////////////////////////
// The one and only CCbreakApp object

CCbreakApp theApp;

/////////////////////////////////////////////////////////////////////////////
// CCbreakApp initialization
ConstantLoader cl;
BOOL CCbreakApp::InitInstance()
{
	extern ConstantLoader cl;
    string out;
	if (!AfxSocketInit())
	{
		AfxMessageBox(IDP_SOCKETS_INIT_FAILED);
		return FALSE;
	} 
	AfxEnableControlContainer();

	// Standard initialization
	// If you are not using these features and wish to reduce the size
	//  of your final executable, you should remove from the following
	//  the specific initialization routines you do not need.

	
#ifdef _AFXDLL
	Enable3dControls();			// Call this when using MFC in a shared DLL
#else
	Enable3dControlsStatic();	// Call this when linking to MFC statically
#endif
      out = ".\\cbreak.ini";
      cl.load_file(&out);

		CSplash * pSplashWnd = new CSplash(IDB_SPLASH,2500);
		pSplashWnd->Create();


	// lets find our lib directory.
	dlg = new CirclemudEditorDlg();
	m_pMainWnd = dlg;
	
	int nResponse = dlg->DoModal();

    delete dlg;

	the_world.zone_list.clear();
	the_world.mob_list.clear();
	the_world.obj_list.clear();
	the_world.room_list.clear();
	the_world.shop_list.clear();
	the_world.obj_files.clear();
	the_world.wld_files.clear();
	the_world.zon_files.clear();
	the_world.shp_files.clear();
	// Since the dialog has been closed, return FALSE so that we exit the
	//  application, rather than start the application's message pump.

	return FALSE;
}


/////////////////////////////////////////////////////////////////////////////
// CAboutDlg dialog used for App About

class CAboutDlg : public CDialog
{
public:
	CAboutDlg();

// Dialog Data
	//{{AFX_DATA(CAboutDlg)
	enum { IDD = IDD_ABOUTBOX };
	//}}AFX_DATA

	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CAboutDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:
	//{{AFX_MSG(CAboutDlg)
		// No message handlers
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

CAboutDlg::CAboutDlg() : CDialog(CAboutDlg::IDD)
{
	//{{AFX_DATA_INIT(CAboutDlg)
	//}}AFX_DATA_INIT
}

void CAboutDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CAboutDlg)
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CAboutDlg, CDialog)
	//{{AFX_MSG_MAP(CAboutDlg)
		// No message handlers
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

// App command to run the dialog
void CCbreakApp::OnAppAbout()
{
	CAboutDlg aboutDlg;
	aboutDlg.DoModal();
}

/////////////////////////////////////////////////////////////////////////////
// CCbreakApp message handlers


void CCbreakApp::OnFileNewzone() 
{
	// TODO: Add your command handler code here
  CNewZoneDlg zoneDlg;
  zoneDlg.DoModal();
}

void CCbreakApp::OnFileNewworld() 
{
  int i;
	// TODO: Add your command handler code here
  dlg->current_mob = dlg->current_obj = dlg->current_room = dlg->current_shop = -1;
  i=dlg->no_world;
  dlg->get_world_dir();
  if(i != dlg->no_world) {
    AfxMessageBox("New World Loaded",MB_OK);
  }
}

void CCbreakApp::OnFileSaveworld() 
{
	map<int,Zone_Data>::const_iterator zi;
	
	for(zi=the_world.zone_list.begin();zi != the_world.zone_list.end();zi++) {
		the_world.save_zone(zi->first);
	}
}

void CCbreakApp::OnEditClear() 
{
	if(dlg->GetFocus()) {
		dlg->GetFocus()->SendMessage(WM_COMMAND,ID_EDIT_CLEAR);
	}
}

void CCbreakApp::OnEditCopy() 
{
	if(dlg->GetFocus()) {
		dlg->GetFocus()->SendMessage(WM_COMMAND,ID_EDIT_COPY);
	}	
}

void CCbreakApp::OnEditCut() 
{
	if(dlg->GetFocus()) {
		dlg->GetFocus()->SendMessage(WM_COMMAND,ID_EDIT_CUT);
	}
}

void CCbreakApp::OnEditPaste() 
{
	if(dlg->GetFocus()) {
		dlg->GetFocus()->SendMessage(WM_COMMAND,ID_EDIT_PASTE);
	}
}

void CCbreakApp::OnEditSelectAll() 
{
	if(dlg->GetFocus()) {
		dlg->GetFocus()->SendMessage(WM_COMMAND,ID_EDIT_SELECT_ALL);
	}
}

void CCbreakApp::OnEditUndo() 
{
	if(dlg->GetFocus()) {
		dlg->GetFocus()->SendMessage(WM_COMMAND,ID_EDIT_UNDO);
	}
}

void CCbreakApp::OnImprovededitFormat() 
{
	if(dlg->GetFocus()) {
		dlg->GetFocus()->SendMessage(WM_COMMAND,ID_IMPROVEDEDIT_FORMAT);
	}
}

void CCbreakApp::OnImprovededitFormati() 
{
	TRACE0("here");
	if(dlg->GetFocus()) {
		dlg->GetFocus()->SendMessage(WM_COMMAND,ID_IMPROVEDEDIT_FORMATI);
	}
}


